Struct HashWriter

pub struct HashWriter { /* private fields */ }
Serializer that outputs a hash of the serialized object

Implementations

Source

impl HashWriter

pub fn finalize(self, output: &mut [u8])

Consume the HashWriter, outputting its current hash into a 32-byte array

pub fn into_hash(self) -> Hash

Consume the HashWriter, outputting a Hash corresponding to its current state