Struct DataFile

pub struct DataFile<T> { /* private fields */ }
Data file (MMR) wrapper around an append-only file.

Implementations

Source

impl<T> DataFile<T>
where T: Readable + Writeable + Debug,

pub fn open<P>( path: P, size_info: SizeInfo, version: ProtocolVersion, ) -> Result<DataFile<T>>
where P: AsRef<Path> + Debug,

Open (or create) a file at the provided path on disk.

pub fn append(&mut self, data: &T) -> Result<u64>

Append an element to the file. Will not be written to disk until flush() is subsequently called. Alternatively discard() may be called to discard any pending changes.

pub fn extend_from_slice(&mut self, data: &[T]) -> Result<u64>

Append a slice of multiple elements to the file. Will not be written to disk until flush() is subsequently called. Alternatively discard() may be called to discard any pending changes.

pub fn read(&self, position: u64) -> Option<T>

Read an element from the file by position. Assumes we have already “shifted” the position to account for pruned data. Note: PMMR API is 1-indexed, but backend storage is 0-indexed.

Makes no assumptions about the size of the elements in bytes. Elements can be of variable size (handled internally in the append-only file impl).

pub fn rewind(&mut self, position: u64)

Rewind the backend file to the specified position.

pub fn flush(&mut self) -> Result<()>

Flush unsynced changes to the file to disk.

pub fn discard(&mut self)

Discard any unsynced changes to the file.

pub fn size(&self) -> u64

Size of the file in number of elements (not bytes).

pub fn path(&self) -> &Path

Path of the underlying file

pub fn release(&mut self)

Drop underlying file handles

pub fn write_tmp_pruned(&self, prune_pos: &[u64]) -> Result<()>

Write the file out to disk, pruning removed elements.

pub fn replace_with_tmp(&mut self) -> Result<()>

Replace with file at tmp path. Rebuild and initialize from new file.