pub trait Readablewhere
Self: Sized,{
// Required method
fn read<R: Reader>(reader: &mut R) -> Result<Self, Error>;
}Expand description
Trait that every type that can be deserialized from binary must implement. Reads directly to a Reader, a utility type thinly wrapping an underlying Read implementation.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.