pub trait Writeable {
// Required method
fn write<W: Writer>(&self, writer: &mut W) -> Result<(), Error>;
}Expand description
Trait that every type that can be serialized as binary must implement. Writes directly to a Writer, a utility type thinly wrapping an underlying Write implementation.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.